import { refreshAccessToken } from './tokenUtils';

export const attachAuthInterceptors = (axiosInstance) => {
  // 요청 시 access token 자동 첨부
  axiosInstance.interceptors.request.use(config => {
    const token = localStorage.getItem('access');
    if (token) {
      config.headers.Authorization = `Bearer ${token}`;
    }
    return config;
  });

  // 응답 시 access 만료 → refresh 재시도
  axiosInstance.interceptors.response.use(
    res => res,
    async err => {
      const originalRequest = err.config;

      if (
        err.response?.status === 401 &&
        !originalRequest._retry &&
        localStorage.getItem('refresh')
      ) {
        originalRequest._retry = true;

        try {
          const newAccess = await refreshAccessToken();
          originalRequest.headers.Authorization = `Bearer ${newAccess}`;
          return axiosInstance(originalRequest);
        } catch (refreshError) {
          console.error('토큰 갱신 실패', refreshError);
          localStorage.removeItem('access');
          localStorage.removeItem('refresh');
          window.location.href = '/login'; // 또는 useNavigate 사용 가능
        }
      }

      return Promise.reject(err);
    }
  );
};
