// src/context/AuthContext.js
import { createContext, useContext, useState, useEffect } from 'react';
import { decodeToken } from '../utils/jwt';  // ✅ JWT 디코딩 유틸 사용

const AuthContext = createContext();

export const AuthProvider = ({ children }) => {
  const [isLoggedIn, setIsLoggedIn] = useState(false);
  const [user, setUser] = useState(null);  // ✅ 추가

  useEffect(() => {
    const token = localStorage.getItem('access');
    if (token) {
      const decoded = decodeToken(token);  // payload 추출
      setUser(decoded);
      setIsLoggedIn(true);
    }
  }, []);

  const login = (tokenObj) => {
    localStorage.setItem('access', tokenObj.access);
    localStorage.setItem('refresh', tokenObj.refresh);
    const decoded = decodeToken(tokenObj.access);
    setUser(decoded);  // ✅ 로그인 시 user 저장
    setIsLoggedIn(true);
  };

  const logout = () => {
    localStorage.removeItem('access');
    localStorage.removeItem('refresh');
    setUser(null);  // ✅ 로그아웃 시 제거
    setIsLoggedIn(false);
  };

  return (
    <AuthContext.Provider value={{ isLoggedIn, login, logout, user }}>
      {children}
    </AuthContext.Provider>
  );
};

export const useAuth = () => useContext(AuthContext);
