import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import EditForm from './EditForm';
import authApi from '../../api/authApi';

function ProfilePage() {
  const navigate = useNavigate();

  const [form, setForm] = useState({
    name: '',
    email: '',
    desc: ''  // ✅ desc 상태 추가
  });

  useEffect(() => {
    const token = localStorage.getItem('access');
    if (!token) {
      navigate('/login');
      return;
    }

    const fetchUser = async () => {
      try {
        const res = await authApi.get('/api/auth/me/');
        const { name, email, desc } = res.data;
        setForm({ name, email, desc });  // ✅ desc 상태 반영
      } catch (err) {
        console.error(err);
        navigate('/login');
      }
    };

    fetchUser();
  }, [navigate]);

  const handleChange = (e) => {
    setForm({ ...form, [e.target.name]: e.target.value });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      await authApi.put('/api/auth/me/', form);  // ✅ desc 포함해서 PUT
      alert('회원정보가 수정되었습니다.');
    } catch (err) {
      console.error(err);
      alert('수정 실패');
    }
  };

  return (
    <div className="container mt-5">
      <EditForm form={form} onChange={handleChange} onSubmit={handleSubmit} />
    </div>
  );
}

export default ProfilePage;
